#
# spec file for package librsb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           librsb
%define lname	librsb0
Version:        1.3.0.2
Release:        1.3
Summary:        Shared memory parallel sparse matrix and sparse BLAS library
License:        LGPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://librsb.sf.net/

Source:         http://downloads.sf.net/%name/%name-%version.tar.gz
Source2:        http://downloads.sf.net/%name/%name-%version.tar.gz.asc
Source9:        %name.keyring
Patch1:         pun.diff
Patch2:         reproducible.patch
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  gsl-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel

%description
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.

%package -n %lname
Summary:        Shared memory parallel sparse matrix and sparse BLAS library
Group:          System/Libraries

%description -n %lname
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.

librsb implements the Sparse BLAS standard, as specified in the BLAS
Forum documents.

%package devel
Summary:        Development files for librsb, a Recursive Sparse Blocks matrix format lirary
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
librsb is a library for sparse matrix computations featuring the
Recursive Sparse Blocks (RSB) matrix format. This format allows cache
efficient and multi-threaded (that is, shared memory parallel)
operations on large sparse matrices.

This subpackage contains libraries and header files for developing
applications that want to make use of librsb.

%prep
%autosetup -p1

%build
autoreconf -fi
# meminfo chosen for smaller machines too
%configure --docdir="%_docdir/%name" --disable-static CFLAGS="%optflags -Wno-unused" \
    --with-memhinfo=L3:16/64/8192K,L2:16/64/2048K,L1:8/64/16K
%make_build -j1

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la
%fdupes %buildroot/%_prefix

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/librsb.so.0*

%files devel
%_includedir/*
%_bindir/rsbench
%_bindir/librsb-config
%_libdir/librsb.so
%_docdir/%name/
%license COPYING

%changelog
* Mon Feb  6 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0.2
  * rsb_coo_sort: fix crash on nr==0 (now will silently accept).
  * Fix a format error on long indices on 32-bit architectures.
* Sat Jul 16 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0.1
  * rsb.h: additional input checks in rsb_mtx_rndr().
  * rsb.hpp: additional input checks in the C++ wrappers.
  * No more unaligned memory access with `rsbench
  - -read-performance-record` (fix for armhf,sparc64 architectures).
* Thu Apr 21 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.3.0.0
  * Considerably improved performance of rsb_spmm()/usmm() via
    new kernels (can be turned off at runtime by setting
    'RSB_WANT_RSBPP=0' in the environment).
  * Added a C++ API (classes RsbMatrix and RsbLib) in new header
    <rsb.hpp>.
  * Environment variable 'RSB_NUM_THREADS' now used by default
    (implicit configure '--enable-rsb-num-threads').
  * Fixed integer overflow situations with limit-large matrices.
  * Improved parallelism of rsb_spmv()/rsb_spmm() a bit (no
    overly strict locking).
  * Improved performance of rsb_spmv()/rsb_spmm() beta-scaling.
* Tue Nov  2 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0.10
  * rsb_spmm(...,RSB_FLAG_WANT_ROW_MAJOR_ORDER,...) internals had
    swapped ldB and ldC so having ldB > ldC could lead to a
    crash; with ldC < ldB, to wrong results.
  * rsb_spmm(...,RSB_FLAG_WANT_ROW_MAJOR_ORDER,...) on matrix
    with RSB_FLAG_UNIT_DIAG_IMPLICIT could have computed wrong
    results.
  * rsb_tune_spmm()/rsb_tune_spsm() could have crashed if called
    with order==RSB_FLAG_WANT_ROW_MAJOR_ORDER and auto leading
    dimensions and implicit operands (ldB==0 and Bp==NULL, ldC==0
    and Cp==NULL).
  * rsb_mtx_get_rows_sparse() with: was ignoring
    RSB_TRANSPOSITION_C.
* Thu Dec 24 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0.9
  * Fixed: rsb_mtx_rndr(..RSB_MARF_EPS) and
    rsb_file_mtx_rndr(..RSB_MARF_EPS): could crash on
    uniform-values matrix input.
  * Fixed: rsb_spmsp was crashing if result matrix has nnz<=rows
  * Fixed: BLAS_zusaxpy and BLAS_cusaxpy in C were crashing
  * Fixed: rsb_sppsp() was ignoring transB and could crash on
    transA
* Thu Mar  5 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.2.0.8
  * bugfix: rsb_spmv/rsb_spmm/BLAS_cusmv/BLAS_zusmv/BLAS_cusmm/
    BLAS_zusmm could compute wrong values in transpose or
    conjugated transpose on very sparse complex hermitian
    matrices.
* Thu Jul 12 2018 bwiedemann@suse.com
- Add reproducible.patch and set an explicit memory hierarchy
  to make build reproducible (boo#1100677)
* Tue Dec 26 2017 jengelh@inai.de
- Update to new upstream release 1.2.0~rc7
  * bugfix: rsb_spmv/rsb_spmm/BLAS_cusmv/BLAS_zusmv/BLAS_cusmm/
    BLAS_zusmm could compute wrong values on complex hermitian
    matrices if rhs imaginary part non null.
  * bugfix: complex conjugated transpose
    rsb_spsv/rsb_spsm/BLAS_cussv/BLAS_zussv/BLAS_cussm/BLAS_zussm
    could compute wrong values if rhs imaginary part non null.
  * bugfix: rsb_sppsp/rsb_mtx_clone would compute scaled
    conjugate of complex matrices wrong if alpha imaginary part
    non null.
  * might detect a forgotten rsb_lib_init() at first matrix
    allocation and return an error.
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 1.2.0~rc6
  * BLAS_zusget_element & co will behave one-based in Fortran.
  * rsb_sppsp was summing incorrectly certain non-overlapping
    sparse matrices.
  * rsb_file_mtx_save and rsb_file_vec_save's output use
    full-precision.
- Add pun.diff
* Thu Oct 20 2016 jengelh@inai.de
- Update to new upstream release 1.2.0~rc5
  * Fixed EPS rendering of matrices, e.g.
  `./rsbench --plot-matrix -aRzd -f matrix.mtx >matrix.eps`
- Drop shlib.diff (applied upstream)
* Wed Jun  8 2016 jengelh@inai.de
- Update to new upstream release 1.2.0~rc3
  * Extension: if parameter flagsA of mtx_set_vals() has
  RSB_FLAG_DUPLICATES_SUM, then values will be summed up into the
  matrix.
  * Bugfix: rsb_mtx_get_nrm on symmetric matrices was buggy.
  * Bugfix: rsb_spsm potentially wrong in --enable-openmp and
  (nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm wrong in --disable-openmp version and
  (nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm used to scale only first rhs when (*alphap!=1
  and nrhs>1). (ussm affected)
  * Bugfix: rsb_spsm used to solve only first rhs when (y != x).
  (ussm not affected)
  * Bugfix: rsb_spmm used to scale only first rhs when (*betap!=1
  and nrhs>1). (usmm not affected)
  * Bugfix: rsb_tune_spmm/rsb_tune_spsm returned (false positive)
  error on ( mtxAp != NULL && mtxOpp != NULL ) rather than on (
  mtxAp != NULL && mtxOpp != NULL && *mtxOpp != NULL ).
  * Will use memset() on systems with no bzero() (e.g. mingw).
* Sun Jan 17 2016 jengelh@inai.de
- Initial package (versoin 1.2.0~rc2) for build.opensuse.org
